@@ -7,7 +7,8 @@
 # Copyright 2013 AKFish <akfish@gmail.com>                                     #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
 #                                                                              #
-# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/          #
+# This file is part of PyGithub.                                               #
+# http://pygithub.github.io/PyGithub/v1/index.html                             #
 #                                                                              #
 # PyGithub is free software: you can redistribute it and/or modify it under    #
 # the terms of the GNU Lesser General Public License as published by the Free  #
@@ -29,6 +30,7 @@ from Authentication import *
 from Authorization import *
 from Branch import *
 from Commit import *
+from CommitCombinedStatus import *
 from CommitComment import *
 from CommitStatus import *
 from ContentFile import *
@@ -40,6 +42,7 @@ from GitBlob import *
 from GitCommit import *
 from Github_ import *
 from GitRef import *
+from GitRelease import *
 from GitTag import *
 from GitTree import *
 from Hook import *
@@ -50,6 +53,7 @@ from Label import *
 from Milestone import *
 from NamedUser import *
 from Markdown import *
+from OrganizationHasInMembers import *
 from Organization import *
 from PullRequest import *
 from PullRequestComment import *
@@ -89,3 +93,5 @@ from Issue158 import *
 from Issue174 import *
 from Issue214 import *
 from Issue216 import *
+from Issue278 import *
+from Issue494 import *
